@@ -1,7 +1,7 @@
 /*
  * test-core-crypto.cpp - test cryptographic functions
  *
- * Copyright (C) 2020-2023 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2020-2024 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -28,8 +28,8 @@ extern "C"
 #include <string.h>
 #include <ctype.h>
 #include <gcrypt.h>
-#include "src/core/wee-crypto.h"
-#include "src/core/wee-string.h"
+#include "src/core/core-crypto.h"
+#include "src/core/core-string.h"
 
 /* Hash */
 #define DATA_HASH_MSG "this is a test of hash function"
